@@ -118,17 +118,20 @@ eog_application_class_init (EogApplicationClass *eog_application_class)
 static void
 eog_application_init (EogApplication *eog_application)
 {
+	const gchar *dot_dir = eog_util_dot_dir ();
+
 	eog_session_init (eog_application);
 
 	eog_application->toolbars_model = egg_toolbars_model_new ();
 
-	eog_application->toolbars_file = g_build_filename
-		(eog_util_dot_dir (), "eog_toolbar.xml", NULL);
-
 	egg_toolbars_model_load_names (eog_application->toolbars_model,
 				       EOG_DATA_DIR "/eog-toolbar.xml");
+
+	if (G_LIKELY (dot_dir != NULL))
+		eog_application->toolbars_file = g_build_filename
+			(dot_dir, "eog_toolbar.xml", NULL);
 	
-	if (!egg_toolbars_model_load_toolbars (eog_application->toolbars_model,
+	if (!dot_dir || !egg_toolbars_model_load_toolbars (eog_application->toolbars_model,
 					       eog_application->toolbars_file)) {
 
 		egg_toolbars_model_load_toolbars (eog_application->toolbars_model,
@@ -199,13 +202,13 @@ eog_application_open_window (EogApplication  *application,
 }
 
 static EogWindow *
-eog_application_get_uri_window (EogApplication *application, GnomeVFSURI *uri)
+eog_application_get_file_window (EogApplication *application, GFile *file)
 {
-	EogWindow *uri_window = NULL;
+	EogWindow *file_window = NULL;
 	GList *windows;
 	GList *l;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (file != NULL, NULL);
 	g_return_val_if_fail (EOG_IS_APPLICATION (application), NULL);
 
 	windows = gtk_window_list_toplevels ();
@@ -216,11 +219,11 @@ eog_application_get_uri_window (EogApplication *application, GnomeVFSURI *uri)
 			
 			if (!eog_window_is_empty (window)) {
 				EogImage *image = eog_window_get_image (window);
-				GnomeVFSURI *window_uri;
+				GFile *window_file;
 				
-				window_uri = eog_image_get_uri (image);
-				if (gnome_vfs_uri_equal (window_uri, uri)) {
-					uri_window = window;
+				window_file = eog_image_get_file (image);
+				if (g_file_equal (window_file, file)) {
+					file_window = window;
 					break;
 				}
 			}
@@ -229,7 +232,7 @@ eog_application_get_uri_window (EogApplication *application, GnomeVFSURI *uri)
 
 	g_list_free (windows);
 	
-	return uri_window;
+	return file_window;
 }
 
 static void
@@ -243,18 +246,18 @@ eog_application_show_window (EogWindow *window, gpointer user_data)
 	gdk_threads_leave ();
 }
 
-static gboolean
-eog_application_real_open_uri_list (EogApplication  *application,
-				    GSList          *uri_list,
-				    guint           timestamp,
-				    EogStartupFlags flags,
-				    GError         **error)
+gboolean
+eog_application_open_file_list (EogApplication  *application,
+				GSList          *file_list,
+				guint           timestamp,
+				EogStartupFlags flags,
+				GError         **error)
 {
 	EogWindow *new_window = NULL;
 
-	if (uri_list != NULL)
-		new_window = eog_application_get_uri_window (application, 
-						     (GnomeVFSURI *) uri_list->data);
+	if (file_list != NULL)
+		new_window = eog_application_get_file_window (application,
+							      (GFile *) file_list->data);
 
 	if (new_window != NULL) {
 		gtk_window_present_with_time (GTK_WINDOW (new_window),
@@ -273,7 +276,7 @@ eog_application_real_open_uri_list (EogApplication  *application,
 			  G_CALLBACK (eog_application_show_window), 
 			  GUINT_TO_POINTER (timestamp));
 
-	eog_window_open_uri_list (new_window, uri_list);
+	eog_window_open_file_list (new_window, file_list);
 
 	return TRUE;
 }
@@ -285,17 +288,17 @@ eog_application_open_uri_list (EogApplication  *application,
  			       EogStartupFlags flags,
  			       GError         **error)
 {
- 	GSList *uri_list = NULL;
+ 	GSList *file_list = NULL;
  
  	g_return_val_if_fail (EOG_IS_APPLICATION (application), FALSE);
  
- 	uri_list = eog_util_string_list_to_uri_list (files);
+ 	file_list = eog_util_string_list_to_file_list (files);
 
- 	return eog_application_real_open_uri_list (application, 
-						   uri_list, 
-						   timestamp,
-						   flags, 
-						   error);
+ 	return eog_application_open_file_list (application,
+					       file_list, 
+					       timestamp,
+					       flags, 
+					       error);
 }
  
 #ifdef HAVE_DBUS
@@ -306,12 +309,12 @@ eog_application_open_uris (EogApplication  *application,
  			   EogStartupFlags flags,
  			   GError        **error)
 {
- 	GSList *uri_list = NULL;
+ 	GSList *file_list = NULL;
  
- 	uri_list = eog_util_strings_to_uri_list (uris);
+ 	file_list = eog_util_strings_to_file_list (uris);
  
- 	return eog_application_real_open_uri_list (application, uri_list, timestamp,
-						   flags, error);
+ 	return eog_application_open_file_list (application, file_list, timestamp,
+						    flags, error);
 }
 #endif
 
@@ -365,9 +368,10 @@ eog_application_get_toolbars_model (EogApplication *application)
 void
 eog_application_save_toolbars_model (EogApplication *application)
 {
-        egg_toolbars_model_save_toolbars (application->toolbars_model,
-			 	          application->toolbars_file, 
-					  "1.0");
+	if (G_LIKELY(application->toolbars_file != NULL))
+        	egg_toolbars_model_save_toolbars (application->toolbars_model,
+				 	          application->toolbars_file, 
+						  "1.0");
 }
 
 void
